@@ -23,6 +23,7 @@
 #include "go-data.h"
 #include "go-data-impl.h"
 #include <goffice/math/go-math.h>
+#include <goffice/math/go-rangefunc.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
@@ -96,7 +97,7 @@ GSF_CLASS_ABSTRACT (GOData, go_data,
  * go_data_dup : 
  * @src : #GOData
  *
- * A deep copy of @src.
+ * Returns: A deep copy of @src.
  **/
 GOData *
 go_data_dup (GOData const *src)
@@ -157,10 +158,10 @@ go_data_preferred_fmt (GOData const *dat)
  * go_data_as_str :
  * @dat : #GOData
  *
- * Return a string representation of the data source that the caller is
- * responsible for freeing
- *
  * NOTE : This is the _source_ not the content.
+ *
+ * Returns: a string representation of the data source that the caller is
+ * 	responsible for freeing
  **/
 char *
 go_data_as_str (GOData const *dat)
@@ -173,11 +174,11 @@ go_data_as_str (GOData const *dat)
 /**
  * go_data_from_str :
  * @dat : #GOData
- * @str :
+ * @str : string to parse
  *
  * De-serializes the source information returned from go_data_as_str.
  *
- * Returns: FALSE on error.
+ * Returns: %FALSE on error.
  **/
 gboolean
 go_data_from_str (GOData *dat, char const *str)
@@ -256,6 +257,8 @@ GSF_CLASS_ABSTRACT (GODataVector, go_data_vector,
 int
 go_data_vector_get_len (GODataVector *vec)
 {
+	if (!vec)
+		return 0;
 	if (! (vec->base.flags & GO_DATA_VECTOR_LEN_CACHED)) {
 		GODataVectorClass const *klass = GO_DATA_VECTOR_GET_CLASS (vec);
 
@@ -332,6 +335,30 @@ go_data_vector_get_minmax (GODataVector *vec, double *min, double *max)
 		*max = vec->maximum;
 }
 
+gboolean
+go_data_vector_increasing (GODataVector *vec)
+{
+	double *data = go_data_vector_get_values (vec);
+	int length = go_data_vector_get_len (vec);
+	return go_range_increasing (data, length);
+}
+
+gboolean
+go_data_vector_decreasing (GODataVector *vec)
+{
+	double *data = go_data_vector_get_values (vec);
+	int length = go_data_vector_get_len (vec);
+	return go_range_decreasing (data, length);
+}
+
+gboolean
+go_data_vector_vary_uniformly (GODataVector *vec)
+{
+	double *data = go_data_vector_get_values (vec);
+	int length = go_data_vector_get_len (vec);
+	return go_range_vary_uniformly (data, length);
+}
+
 /*************************************************************************/
 
 #define GO_DATA_MATRIX_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST ((k), GO_DATA_MATRIX_TYPE, GODataMatrixClass))
@@ -357,9 +384,11 @@ GSF_CLASS_ABSTRACT (GODataMatrix, go_data_matrix,
 GODataMatrixSize
 go_data_matrix_get_size (GODataMatrix *mat)
 {
+	static GODataMatrixSize null_size = {0, 0};
+	if (!mat)
+		return null_size;
 	if (! (mat->base.flags & GO_DATA_MATRIX_SIZE_CACHED)) {
 		GODataMatrixClass const *klass = GO_DATA_MATRIX_GET_CLASS (mat);
-		static GODataMatrixSize null_size = {0, 0};
 
 		g_return_val_if_fail (klass != NULL, null_size);
 
