@@ -37,20 +37,11 @@
 
 #ifdef GOFFICE_WITH_GTK
 #include <goffice/gtk/goffice-gtk.h>
-#include <goffice/gtk/goffice-gtk.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcelllayout.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtktogglebutton.h>
 #endif
 
 #include <glib/gi18n-lib.h>
 #include <string.h>
 
-static double gog_axis_base_get_cross_location (GogAxisBase *axis_base);
-
 static GogViewClass *gab_view_parent_klass;
 static GObjectClass *gab_parent_klass;
 
@@ -294,7 +285,7 @@ gog_axis_base_get_crossed_axis_type (GogAxisBase *axis_base)
 	return crossed_type;
 }
 
-static GogAxis *
+GogAxis *
 gog_axis_base_get_crossed_axis (GogAxisBase *axis_base)
 {
 	GogAxis *crossed_axis = NULL;
@@ -772,7 +763,7 @@ gog_axis_base_init (GogAxisBase *gab)
 	gab->minor.size_pts = 2;
 }
 
-static double
+double
 gog_axis_base_get_cross_location (GogAxisBase *axis_base)
 {
 	GOData *data;
@@ -2196,7 +2187,7 @@ gog_axis_base_view_label_position_request (GogView *view,
 	GogAxisSet axis_set;
 	GogAxisBase *axis_base = GOG_AXIS_BASE (view->model);
 	GogStyle *style = axis_base->base.style;
-	GogViewPadding padding;
+	GogViewPadding padding = {0};
 
 	if (gog_axis_get_atype (axis_base->axis) >= GOG_AXIS_VIRTUAL)
 		return;
