@@ -45,17 +45,6 @@
 #ifdef GOFFICE_WITH_GTK
 #include <goffice/gtk/goffice-gtk.h>
 #include <goffice/gtk/go-format-sel.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcelllayout.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkmisc.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtktogglebutton.h>
 #endif
 
 #include <string.h>
@@ -149,6 +138,7 @@ struct _GogAxisMap {
 struct _GogAxisMapDesc {
 	double 		(*map) 		 (GogAxisMap *map, double value);
 	double 		(*map_to_view)   (GogAxisMap *map, double value);
+	double 		(*map_derivative_to_view)   (GogAxisMap *map, double value);
 	double 		(*map_from_view) (GogAxisMap *map, double value);
 	gboolean	(*map_finite)    (double value);
 	double		(*map_baseline)  (GogAxisMap *map);
@@ -216,6 +206,16 @@ map_discrete_to_view (GogAxisMap *map, double value)
 		value * data->a + data->b;
 }
 
+static double
+map_discrete_derivative_to_view (GogAxisMap *map, double value)
+{
+	/* WARNING: does this makes sense? */
+	MapData *data = map->data;
+
+	return map->axis->inverted ? -data->a: data->a;
+
+}
+
 static double
 map_discrete_from_view (GogAxisMap *map, double value)
 {
@@ -351,6 +351,15 @@ map_linear_to_view (GogAxisMap *map, double value)
 		value * data->a + data->b;
 }
 
+static double
+map_linear_derivative_to_view (GogAxisMap *map, double value)
+{
+	MapData *data = map->data;
+
+	return map->axis->inverted ? -data->a: data->a;
+
+}
+
 static double
 map_linear_from_view (GogAxisMap *map, double value)
 {
@@ -571,6 +580,18 @@ map_log_to_view (GogAxisMap *map, double value)
 	return result;
 }
 
+static double
+map_log_derivative_to_view (GogAxisMap *map, double value)
+{
+	MapLogData *data = map->data;
+
+	if (value <= 0.)
+		return go_nan;
+	return map->axis->inverted ? data->a_inv / value:
+		data->a / value;
+
+}
+
 static double
 map_log_from_view (GogAxisMap *map, double value)
 {
@@ -704,7 +725,7 @@ map_log_calc_ticks (GogAxis *axis)
 
 static const GogAxisMapDesc map_desc_discrete = 
 {
-	map_discrete,			map_discrete_to_view,
+	map_discrete,			map_discrete_to_view,   map_discrete_derivative_to_view,
 	map_discrete_from_view,		go_finite,
 	map_baseline,			map_bounds,
 	map_discrete_init,		NULL,
@@ -715,7 +736,7 @@ static const GogAxisMapDesc map_desc_discrete =
 static const GogAxisMapDesc map_descs[] = 
 {
 	{
-		map_linear,		map_linear_to_view,
+		map_linear,		map_linear_to_view,     map_linear_derivative_to_view,
 		map_linear_from_view,   go_finite,
 		map_baseline,		map_bounds,
 		map_linear_init, 	NULL,	
@@ -723,7 +744,7 @@ static const GogAxisMapDesc map_descs[] =
 		N_("Linear"),		N_("Linear mapping")
 	},
 	{
-		map_log,		map_log_to_view,
+		map_log,		map_log_to_view,	map_log_derivative_to_view,
 		map_log_from_view,	map_log_finite,
 		map_log_baseline,	map_log_bounds,
 		map_log_init,		NULL,	
@@ -882,6 +903,21 @@ gog_axis_map_to_view (GogAxisMap *map,
 	return map->desc->map_to_view (map, value);
 }
 
+/**
+ * gog_axis_map_to_view :
+ * @map : a #GogAxisMap
+ * @value : value to map to canvas space
+ *
+ * Returns: the derivative of the mapping expression at value.
+ **/
+
+double 
+gog_axis_map_derivative_to_view (GogAxisMap *map,
+		      double value)
+{
+	return map->desc->map_derivative_to_view (map, value);
+}
+
 /**
  * gog_axis_map_finite :
  * @map : a #GogAxisMap
