@@ -36,9 +36,6 @@
 
 #include <glib/gi18n-lib.h>
 
-#include <libart_lgpl/art_render_gradient.h>
-#include <libart_lgpl/art_render_svp.h>
-#include <libart_lgpl/art_render_mask.h>
 #include <pango/pangocairo.h>
 
 #include <cairo.h>
@@ -113,86 +110,6 @@ typedef struct {
 
 #define GRC_LINEAR_SCALE(w,scale) (go_sub_epsilon (w) <= 0.0 ? GOG_RENDERER_HAIRLINE_WIDTH_PTS : w) * scale
 
-static void
-grc_path_raw (cairo_t *cr, ArtVpath *vpath, ArtBpath *bpath)
-{
-	if (vpath) {
-		while (vpath->code != ART_END) {
-			switch (vpath->code) {
-				case ART_MOVETO_OPEN:
-				case ART_MOVETO:
-					cairo_move_to (cr, GO_CAIRO_CLAMP (vpath->x),
-						       GO_CAIRO_CLAMP (vpath->y));
-					break;
-				case ART_LINETO:
-					cairo_line_to (cr, GO_CAIRO_CLAMP (vpath->x),
-						       GO_CAIRO_CLAMP (vpath->y));
-					break;
-				default:
-					break;
-			}
-			vpath++;
-		}
-	} else
-		while (bpath->code != ART_END) {
-			switch (bpath->code) {
-				case ART_MOVETO_OPEN:
-				case ART_MOVETO:
-					cairo_move_to (cr, GO_CAIRO_CLAMP (bpath->x3),
-						       GO_CAIRO_CLAMP (bpath->y3));
-					break;
-				case ART_LINETO:
-					cairo_line_to (cr, GO_CAIRO_CLAMP (bpath->x3),
-						       GO_CAIRO_CLAMP (bpath->y3));
-					break;
-				case ART_CURVETO:
-					cairo_curve_to (cr, GO_CAIRO_CLAMP (bpath->x1),
-							GO_CAIRO_CLAMP (bpath->y1),
-							GO_CAIRO_CLAMP (bpath->x2),
-							GO_CAIRO_CLAMP (bpath->y2),
-							GO_CAIRO_CLAMP (bpath->x3),
-							GO_CAIRO_CLAMP (bpath->y3));
-					break;
-				default:
-					break;
-			}
-			bpath++;
-		}
-}
-
-static void
-grc_path_sharp (cairo_t *cr, ArtVpath *vpath, ArtBpath *bpath, double line_width)
-{
-	gboolean even = ((int) (go_fake_ceil (line_width)) % 2 == 0) && line_width > 1.0;
-
-	if (vpath)
-		while (vpath->code != ART_END) {
-			switch (vpath->code) {
-				case ART_MOVETO_OPEN:
-				case ART_MOVETO:
-					cairo_move_to (cr, GO_CAIRO_CLAMP_SNAP (vpath->x, even),
-						           GO_CAIRO_CLAMP_SNAP (vpath->y, even));
-					break;
-				case ART_LINETO:
-					cairo_line_to (cr, GO_CAIRO_CLAMP_SNAP (vpath->x, even),
-						           GO_CAIRO_CLAMP_SNAP (vpath->y, even));
-					break;
-				default:
-					break;
-			}
-			vpath++;
-		}
-}
-
-static void
-grc_path (cairo_t *cr, ArtVpath *vpath, ArtBpath *bpath, double line_width, gboolean sharp)
-{
-	if (sharp)
-		grc_path_sharp (cr, vpath, bpath, line_width);
-	else
-		grc_path_raw (cr, vpath, bpath);
-}
-
 static double
 _grc_line_size (GogRenderer const *rend, double width, gboolean sharp)
 {
@@ -680,155 +597,6 @@ gog_renderer_pop_clip (GogRenderer *rend)
 	cairo_restore (rend->cairo);
 }
 
-/*****************************************************************************/
-
-static void
-grc_draw_path (GogRenderer *rend, ArtVpath const *vpath, ArtBpath const*bpath, gboolean sharp)
-{
-	GogStyle const *style = rend->cur_style;
-
-	if (gog_style_is_line_visible (style)) {
-		gboolean legend_line;
-		double width;
-
-		/* KLUDGE snap coordinate of legend line sample. */
-		legend_line =!sharp
-			&& !rend->is_vector
-			&& vpath != NULL
-			&& vpath[0].code == ART_MOVETO
-			&& vpath[1].code == ART_LINETO
-			&& vpath[2].code == ART_END
-			&& (vpath[0].x == vpath[1].x || vpath[0].y == vpath[1].y);
-
-		width = _grc_line_size (rend, style->line.width, sharp);
-
-		grc_path (rend->cairo, (ArtVpath *) vpath, (ArtBpath *) bpath, width,
-			  (sharp || legend_line) && !rend->is_vector);
-		emit_line (rend, FALSE, sharp ? GO_PATH_OPTIONS_SHARP : 0);
-	}
-
-}
-
-static void
-grc_draw_polygon (GogRenderer *rend, ArtVpath const *vpath, ArtBpath const *bpath,
-		  gboolean sharp, gboolean narrow)
-{
-	GogStyle const *style;
-	double width;
-	gboolean is_outline_visible, is_fill_visible;
-
-	style = rend->cur_style;
-
-	is_outline_visible = gog_style_is_outline_visible (style) && !narrow;
-	is_fill_visible = gog_style_is_fill_visible (style);
-
-	if (!is_outline_visible && !is_fill_visible)
-		return;
-
-        width = _grc_line_size (rend, style->outline.width, sharp);
-
-	grc_path (rend->cairo, (ArtVpath *) vpath, (ArtBpath *) bpath, width,
-		  sharp && !rend->is_vector);
-
-	if (is_fill_visible)
-		emit_fill (rend, is_outline_visible);
-
-	if (is_outline_visible)
-		emit_outline (rend, FALSE, sharp ? GO_PATH_OPTIONS_SHARP : 0);
-}
-
-/**
- * gog_renderer_draw_sharp_path :
- * @rend : #GogRenderer
- * @path  : #ArtVpath
- *
- * Draws @path using the outline elements of the current style,
- * trying to make line with sharp edge.
- **/
-
-void
-gog_renderer_draw_sharp_path (GogRenderer *rend, ArtVpath *path)
-{
-	g_return_if_fail (IS_GOG_RENDERER (rend));
-	g_return_if_fail (rend->cur_style != NULL);
-
-	grc_draw_path (rend, path, NULL, TRUE);
-}
-
-/**
- * gog_renderer_draw_path :
- * @rend: #GogRenderer
- * @path: #ArtVpath
- *
- * Draws @path using the outline elements of the current style.
- **/
-
-void
-gog_renderer_draw_path (GogRenderer *rend, ArtVpath const *path)
-{
-	g_return_if_fail (IS_GOG_RENDERER (rend));
-	g_return_if_fail (rend->cur_style != NULL);
-
-	grc_draw_path (rend, path, NULL, FALSE);
-}
-
-/**
- * gog_renderer_draw_sharp_polygon :
- * @rend : #GogRenderer
- * @path  : #ArtVpath
- * @narrow : if TRUE skip any outline the current style specifies.
- *
- * Draws @path and fills it with the fill elements of the current style,
- * trying to draw line with sharp edge.
- * If @narrow is false it alos outlines it using the outline elements.
- **/
-
-void
-gog_renderer_draw_sharp_polygon (GogRenderer *rend, ArtVpath *path, gboolean narrow)
-{
-	g_return_if_fail (IS_GOG_RENDERER (rend));
-	g_return_if_fail (rend->cur_style != NULL);
-
-	grc_draw_polygon (rend, path, NULL, TRUE, narrow);
-}
-
-/**
- * gog_renderer_draw_polygon :
- * @rend : #GogRenderer
- * @path  : #ArtVpath
- * @narrow : if TRUE skip any outline the current style specifies.
- *
- * Draws @path and fills it with the fill elements of the current style.
- * If @narrow is false it alos outlines it using the outline elements.
- **/
-
-void
-gog_renderer_draw_polygon (GogRenderer *rend, ArtVpath const *path, gboolean narrow)
-{
-	g_return_if_fail (IS_GOG_RENDERER (rend));
-	g_return_if_fail (rend->cur_style != NULL);
-
-	grc_draw_polygon (rend, path, NULL, FALSE, narrow);
-}
-
-
-/**
- * gog_renderer_draw_bezier_path :
- * @rend : #GogRenderer
- * @path  : #ArtBpath
- *
- * Draws @path using the outline elements of the current style.
- **/
-
-void
-gog_renderer_draw_bezier_path (GogRenderer *rend, ArtBpath const *path)
-{
-	g_return_if_fail (IS_GOG_RENDERER (rend));
-	g_return_if_fail (rend->cur_style != NULL);
-
-	grc_draw_path (rend, NULL, path, FALSE);
-}
-
 static void
 _draw_circle (GogRenderer *rend, double x, double y, double r, gboolean fill, gboolean stroke)
 {
@@ -1503,72 +1271,63 @@ gog_renderer_export_image (GogRenderer *rend, GOImageFormat format,
 
 	switch (format) {
 		case GO_IMAGE_FORMAT_EPS:
-		case GO_IMAGE_FORMAT_PDF:
-		case GO_IMAGE_FORMAT_PS:
-		case GO_IMAGE_FORMAT_SVG:
-			rend->scale = 1.0;
-			switch (format) {
-				case GO_IMAGE_FORMAT_PDF:
-					rend->marker_as_surface = FALSE;
-#ifdef CAIRO_HAS_PDF_SURFACE
-					surface = cairo_pdf_surface_create_for_stream
-						(_cairo_write_func,
-						 output, width_in_pts, height_in_pts);
-#ifdef HAVE_CAIRO_SURFACE_SET_FALLBACK_RESOLUTION
-					cairo_surface_set_fallback_resolution (surface, x_dpi, y_dpi);
-#endif
-					break;
-#else
-					g_warning ("[GogRendererCairo::export_image] cairo PDF backend missing");
-					return FALSE;
-#endif
-				case GO_IMAGE_FORMAT_PS:
-					rend->marker_as_surface = FALSE;
-#ifdef CAIRO_HAS_PS_SURFACE
-					surface = cairo_ps_surface_create_for_stream
-						(_cairo_write_func,
-						 output, width_in_pts, height_in_pts);
-#ifdef HAVE_CAIRO_SURFACE_SET_FALLBACK_RESOLUTION
-					cairo_surface_set_fallback_resolution (surface, x_dpi, y_dpi);
-#endif
-					break;
-#else
-					g_warning ("[GogRendererCairo::export_image] cairo PS backend missing");
-					return FALSE;
-#endif
-				case GO_IMAGE_FORMAT_SVG:
-					rend->marker_as_surface = TRUE;
-#ifdef CAIRO_HAS_SVG_SURFACE
-					surface = cairo_svg_surface_create_for_stream
-						(_cairo_write_func,
-						 output, width_in_pts, height_in_pts);
-#ifdef HAVE_CAIRO_SURFACE_SET_FALLBACK_RESOLUTION
-					cairo_surface_set_fallback_resolution (surface, x_dpi, y_dpi);
-#endif
-					break;
-#else
-					g_warning ("[GogRendererCairo::export_image] cairo SVG backend missing");
-					return FALSE;
-#endif
-				case GO_IMAGE_FORMAT_EPS:
-					rend->marker_as_surface = FALSE;
+			rend->marker_as_surface = FALSE;
 #ifdef HAVE_CAIRO_PS_SURFACE_SET_EPS
-					surface = cairo_ps_surface_create_for_stream
-						(_cairo_write_func,
-						 output, width_in_pts, height_in_pts);
-					cairo_ps_surface_set_eps (surface, TRUE);
+			surface = cairo_ps_surface_create_for_stream
+				(_cairo_write_func,
+				 output, width_in_pts, height_in_pts);
+			cairo_ps_surface_set_eps (surface, TRUE);
 #ifdef HAVE_CAIRO_SURFACE_SET_FALLBACK_RESOLUTION
-					cairo_surface_set_fallback_resolution (surface, x_dpi, y_dpi);
+			cairo_surface_set_fallback_resolution (surface, x_dpi, y_dpi);
 #endif
-					break;
+			goto do_export_vectorial;
 #else
-					g_warning ("[GogRendererCairo::export_image] cairo EPS backend missing");
-					return FALSE;
+			g_warning ("[GogRendererCairo::export_image] cairo EPS backend missing");
+			return FALSE;
 #endif
-				default:
-					break;
-			}
-
+		case GO_IMAGE_FORMAT_PDF:
+			rend->marker_as_surface = FALSE;
+#ifdef CAIRO_HAS_PDF_SURFACE
+			surface = cairo_pdf_surface_create_for_stream
+				(_cairo_write_func,
+				 output, width_in_pts, height_in_pts);
+#ifdef HAVE_CAIRO_SURFACE_SET_FALLBACK_RESOLUTION
+			cairo_surface_set_fallback_resolution (surface, x_dpi, y_dpi);
+#endif
+			goto do_export_vectorial;
+#else
+			g_warning ("[GogRendererCairo::export_image] cairo PDF backend missing");
+			return FALSE;
+#endif
+		case GO_IMAGE_FORMAT_PS:
+			rend->marker_as_surface = FALSE;
+#ifdef CAIRO_HAS_PS_SURFACE
+			surface = cairo_ps_surface_create_for_stream
+				(_cairo_write_func,
+				 output, width_in_pts, height_in_pts);
+#ifdef HAVE_CAIRO_SURFACE_SET_FALLBACK_RESOLUTION
+			cairo_surface_set_fallback_resolution (surface, x_dpi, y_dpi);
+#endif
+			goto do_export_vectorial;
+#else
+			g_warning ("[GogRendererCairo::export_image] cairo PS backend missing");
+			return FALSE;
+#endif
+		case GO_IMAGE_FORMAT_SVG:
+			rend->marker_as_surface = TRUE;
+#ifdef CAIRO_HAS_SVG_SURFACE
+			surface = cairo_svg_surface_create_for_stream
+				(_cairo_write_func,
+				 output, width_in_pts, height_in_pts);
+#ifdef HAVE_CAIRO_SURFACE_SET_FALLBACK_RESOLUTION
+			cairo_surface_set_fallback_resolution (surface, x_dpi, y_dpi);
+#endif
+#else
+			g_warning ("[GogRendererCairo::export_image] cairo SVG backend missing");
+			return FALSE;
+#endif
+do_export_vectorial:
+			rend->scale = 1.0;
 			cairo = cairo_create (surface);
 			cairo_surface_destroy (surface);
 			status = gog_renderer_render_to_cairo (rend, cairo, width_in_pts, height_in_pts);
@@ -1633,6 +1392,29 @@ gog_renderer_get_hairline_width_pts (GogRenderer const *rend)
 
 	return 1.0 / rend->scale;
 }
+#ifdef GOFFICE_WITH_GMATHML
+
+void
+gog_renderer_draw_equation (GogRenderer *renderer, GMathmlView *mathml_view, double x, double y)
+{
+	cairo_t *cairo;
+
+	g_return_if_fail (IS_GOG_RENDERER (renderer));
+	g_return_if_fail (GMATHML_IS_VIEW (mathml_view));
+
+	cairo = renderer->cairo;
+
+	cairo_save (cairo);
+
+	cairo_scale (cairo, renderer->scale_x, renderer->scale_y);
+
+	gmathml_view_set_cairo (mathml_view, cairo);
+	gmathml_view_render (mathml_view, x / renderer->scale_x, y / renderer->scale_y);
+
+	cairo_restore (cairo);
+}
+
+#endif
 
 /**
  * gog_renderer_new:
