@@ -47,16 +47,6 @@
 #include <goffice/gtk/go-image-sel.h>
 
 #include <glade/glade-xml.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkrange.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtksizegroup.h>
 #include <gdk-pixbuf/gdk-pixdata.h>
 #endif
 
@@ -929,7 +919,7 @@ text_layout_init (StylePrefState *state, guint32 enable, GogEditor *editor, GOCm
 	g_signal_connect (G_OBJECT (w), "rotation-changed",
 		G_CALLBACK (cb_angle_changed), state);
 	box = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start_defaults (GTK_BOX (box), w);
+	gtk_box_pack_start (GTK_BOX (box), w, TRUE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (box), 12);
 	gog_editor_add_page (editor, box, _("Text"));
 }
@@ -1788,8 +1778,11 @@ gog_style_sax_load_font (GsfXMLIn *xin, xmlChar const **attrs)
 			go_color_from_str (attrs[1], &style->font.color);
 		else if (0 == strcmp (attrs[0], "font")) {
 			PangoFontDescription *desc = pango_font_description_from_string (attrs[1]);
-			if (desc != NULL)
+			if (desc != NULL) {
+				if (pango_font_description_get_family (desc) == NULL)
+					pango_font_description_set_family_static (desc, "Sans");
 				gog_style_set_font_desc (style, desc);
+			}
 		} else if (bool_sax_prop ("auto-scale", attrs[0], attrs[1], &style->font.auto_scale))
 			;
 }
