@@ -31,13 +31,13 @@
 #include <glib/gi18n-lib.h>
 #include <gsf/gsf-input-gio.h>
 #include <gsf/gsf-output-gio.h>
-#ifdef GOFFICE_WITH_GNOME
-#include <libgnome/gnome-url.h>
-#elif defined G_OS_WIN32
-#include <urlmon.h>
+#ifdef G_OS_WIN32
+#include <windows.h>
 #include <io.h>
 #endif
-
+#ifdef HAVE_GTK_SHOW_URI
+#include <gtk/gtk.h>
+#endif
 #include <string.h>
 #include <stdlib.h>
 #ifdef HAVE_UNISTD_H
@@ -50,6 +50,36 @@
 #include <grp.h>
 #endif
 #include <time.h>
+
+#ifdef G_OS_WIN32
+typedef HRESULT (* STDCALL FindMimeFromData_t) (LPBC pBC,
+						LPCWSTR pwzUrl,
+						LPVOID pBuffer,
+						DWORD cbSize,
+						LPCWSTR pwzMimeProposed,
+						DWORD dwMimeFlags,
+						LPWSTR *ppwzMimeOut,
+						DWORD dwReserved);
+#define FMFD_ENABLEMIMESNIFFING 2
+
+static FindMimeFromData_t
+find_mime_from_data (void)
+{
+	HMODULE urlmon;
+	static FindMimeFromData_t result = NULL;
+	static gboolean beenhere = FALSE;
+
+	if (!beenhere) {
+		urlmon = LoadLibrary ("urlmon.dll");
+		if (urlmon != NULL)
+			result = (FindMimeFromData_t) GetProcAddress (urlmon, "FindMimeFromData");
+		beenhere = TRUE;
+	}
+
+	return result;
+}
+
+#endif
 /* ------------------------------------------------------------------------- */
 
 /*
@@ -401,6 +431,11 @@ is_fd_uri (char const *uri, int *fd)
 		return FALSE;  /* Space, for example.  */
 
 	ul = strtoul (uri, &end, 10);
+
+	/* Accept a terminating slash because go_shell_arg_to_uri will add
+	   one. */
+	if (*end == '/') end++;
+
 	if (*end != 0 || ul > INT_MAX)
 		return FALSE;
 
@@ -669,6 +704,7 @@ go_get_file_permissions (char const *uri)
 					     G_FILE_QUERY_INFO_NONE, NULL, &error);
 	if (error) {
 		g_error_free (error);
+		error = NULL;
 	   	info = g_file_query_info (file,
 					    	     G_FILE_ATTRIBUTE_ACCESS_CAN_READ","G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE","G_FILE_ATTRIBUTE_ACCESS_CAN_EXECUTE,
 						     G_FILE_QUERY_INFO_NONE, NULL, &error);
@@ -922,23 +958,6 @@ go_url_encode (gchar const *text, int type)
 	return g_string_free (result, FALSE);
 }
 
-#ifndef GOFFICE_WITH_GNOME
-#ifndef G_OS_WIN32
-static char *
-check_program (char const *prog)
-{
-	if (NULL == prog)
-		return NULL;
-	if (g_path_is_absolute (prog)) {
-		if (!g_file_test (prog, G_FILE_TEST_IS_EXECUTABLE))
-			return NULL;
-	} else if (!g_find_program_in_path (prog))
-		return NULL;
-	return g_strdup (prog);
-}
-#endif
-#endif
-
 GError *
 go_url_show (gchar const *url)
 {
@@ -946,76 +965,14 @@ go_url_show (gchar const *url)
 	ShellExecute (NULL, "open", url, NULL, NULL, SW_SHOWNORMAL);
 
 	return NULL;
+#elif defined(HAVE_GTK_SHOW_URI)
+	GError *error = NULL;
+	gtk_show_uri (NULL, url, GDK_CURRENT_TIME, &error);
+	return error;
 #else
-	GError *err = NULL;
-#ifdef GOFFICE_WITH_GNOME
-	gnome_url_show (url, &err);
-	return err;
-#else
-	guint8 *browser = NULL;
-	guint8 *clean_url = NULL;
-
-	/* 1) Check BROWSER env var */
-	browser = check_program (getenv ("BROWSER"));
-
-	if (browser == NULL) {
-		static char const * const browsers[] = {
-			"sensible-browser",	/* debian */
-			"epiphany",		/* primary gnome */
-			"galeon",		/* secondary gnome */
-			"encompass",
-			"firefox",
-			"mozilla-firebird",
-			"mozilla",
-			"netscape",
-			"konqueror",
-			"xterm -e w3m",
-			"xterm -e lynx",
-			"xterm -e links"
-		};
-		unsigned i;
-		for (i = 0 ; i < G_N_ELEMENTS (browsers) ; i++)
-			if (NULL != (browser = check_program (browsers[i])))
-				break;
-  	}
-
-	if (browser != NULL) {
-		gint    argc;
-		gchar **argv = NULL;
-		char   *cmd_line = g_strconcat (browser, " %1", NULL);
-
-		if (g_shell_parse_argv (cmd_line, &argc, &argv, &err)) {
-			/* check for '%1' in an argument and substitute the url
-			 * otherwise append it */
-			gint i;
-			char *tmp;
-
-			for (i = 1 ; i < argc ; i++)
-				if (NULL != (tmp = strstr (argv[i], "%1"))) {
-					*tmp = '\0';
-					tmp = g_strconcat (argv[i],
-						(clean_url != NULL) ? (char const *)clean_url : url,
-						tmp+2, NULL);
-					g_free (argv[i]);
-					argv[i] = tmp;
-					break;
-				}
-
-			/* there was actually a %1, drop the one we added */
-			if (i != argc-1) {
-				g_free (argv[argc-1]);
-				argv[argc-1] = NULL;
-			}
-			g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
-				NULL, NULL, NULL, &err);
-			g_strfreev (argv);
-		}
-		g_free (cmd_line);
-	}
-	g_free (browser);
-	g_free (clean_url);
-	return err;
-#endif
+	GError *error = NULL;
+	g_app_info_launch_default_for_uri (url, NULL, &error);
+	return error;
 #endif
 }
 
@@ -1070,10 +1027,10 @@ go_get_mime_type (gchar const *uri)
 
 	wuri = g_utf8_to_utf16 (uri, -1, NULL, NULL, NULL);
 	if (wuri &&
-	    FindMimeFromData (NULL, wuri,
-			      NULL, 0,
-			      NULL, FMFD_ENABLEMIMESNIFFING, &mime_type, 0) == NOERROR)
-	{
+	    find_mime_from_data () &&
+	    (find_mime_from_data ()) (NULL, wuri,
+				      NULL, 0,
+				      NULL, FMFD_ENABLEMIMESNIFFING, &mime_type, 0) == NOERROR)	{
 		g_free (wuri);
 		return g_utf16_to_utf8 (mime_type, -1, NULL, NULL, NULL);
 	}
@@ -1087,7 +1044,7 @@ go_get_mime_type (gchar const *uri)
 	 */
 	return g_strdup ("text/plain");
 #else
-	GFile *file = g_vfs_get_file_for_uri (g_vfs_get_default (), uri);
+	GFile *file = g_file_new_for_uri (uri);
 	GError *error = NULL;
 	gchar *content_type = NULL, *mime_type = NULL;
 	GFileInfo *info = g_file_query_info (file,
@@ -1120,10 +1077,10 @@ go_get_mime_type_for_data (gconstpointer data, int data_size)
 	/* Do we really need that? */
 	LPWSTR mime_type;
 
-	if (FindMimeFromData (NULL, NULL,
-			      (LPVOID)data, data_size,
-			      NULL, FMFD_ENABLEMIMESNIFFING, &mime_type, 0) == NOERROR)
-	{
+	if (find_mime_from_data () &&
+	    (find_mime_from_data ()) (NULL, NULL,
+				      (LPVOID)data, data_size,
+				      NULL, FMFD_ENABLEMIMESNIFFING, &mime_type, 0) == NOERROR)	{
 		return g_utf16_to_utf8 (mime_type, -1, NULL, NULL, NULL);
 	}
 
