@@ -31,6 +31,7 @@
 #include <goffice/data/go-data.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-color.h>
+#include <goffice/utils/go-persist.h>
 
 #include <glib/gi18n-lib.h>
 #include <gsf/gsf-impl-utils.h>
@@ -240,19 +241,19 @@ gog_barcol_plot_class_init (GogPlot1_5dClass *gog_plot_1_5d_klass)
 			_("Gap percentage"),
 			_("The padding around each group as a percentage of their width"),
 			0, 500, 150, 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, BARCOL_PROP_OVERLAP_PERCENTAGE,
 		g_param_spec_int ("overlap-percentage", 
 			_("Overlap percentage"),
 			_("The distance between series as a percentage of their width"),
 			-100, 100, 0, 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, BARCOL_PROP_HORIZONTAL,
 		g_param_spec_boolean ("horizontal", 
 			_("horizontal"),
 			_("horizontal bars or vertical columns"),
 			FALSE,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 
 	gog_object_klass->type_name	= gog_barcol_plot_type_name;
 	gog_object_klass->populate_editor	= gog_barcol_plot_populate_editor;
@@ -302,7 +303,7 @@ barcol_draw_rect (GogRenderer *rend, gboolean flip,
 		  GogAxisMap *y_map,
 		  GogViewAllocation const *rect)
 {
-	ArtVpath path[6];
+	GOPath *path = go_path_new ();
 	double x0, x1, y0, y1;
 
 	if (flip) {
@@ -329,19 +330,15 @@ barcol_draw_rect (GogRenderer *rend, gboolean flip,
 		y1 = gog_axis_map_to_view (y_map, rect->y + rect->h);
 	}
 
-	path[0].x = path[3].x = path[4].x = x0;
-	path[1].x = path[2].x = x1;
-	path[0].y = path[1].y = path[4].y = y0;
-	path[2].y = path[3].y = y1;
-	path[0].code = ART_MOVETO;
-	path[1].code = ART_LINETO;
-	path[2].code = ART_LINETO;
-	path[3].code = ART_LINETO;
-	path[4].code = ART_LINETO;
-	path[5].code = ART_END;
-	
-	gog_renderer_draw_sharp_polygon (rend, path, 
-					 fabs (x1 - x0) < 3. || fabs (y1 - y0) < 3.);
+	go_path_move_to (path, x0, y0);
+	go_path_line_to (path, x1, y0);
+	go_path_line_to (path, x1, y1);
+	go_path_line_to (path, x0, y1);
+	go_path_close (path);
+	go_path_set_options (path, GO_PATH_OPTIONS_SHARP);
+
+	gog_renderer_draw_shape (rend, path);
+	go_path_free (path);
 }
 
 typedef struct {
@@ -381,7 +378,7 @@ gog_barcol_view_render (GogView *view, GogViewAllocation const *bbox)
 	double plus, minus;
 	GogObjectRole const *role = NULL;
 	GogSeriesElement *gse;
-	GList const *overrides;
+	GList const **overrides;
 
 	if (num_elements <= 0 || num_series <= 0)
 		return;
@@ -408,6 +405,7 @@ gog_barcol_view_render (GogView *view, GogViewAllocation const *bbox)
 	error_data = g_alloca (num_series * sizeof (ErrorBarData *));
 	lines = g_alloca (num_series * sizeof (GogSeriesLines *));
 	paths = g_alloca (num_series * sizeof (GOPath *));
+	overrides = g_alloca (num_series * sizeof (GSList *));
 	
 	i = 0;
 	for (ptr = gog_1_5d_model->base.series ; ptr != NULL ; ptr = ptr->next) {
@@ -420,6 +418,7 @@ gog_barcol_view_render (GogView *view, GogViewAllocation const *bbox)
 			GO_DATA_VECTOR (series->base.values[1].data));
 		styles[i] = GOG_STYLED_OBJECT (series)->style;
 		errors[i] = series->errors;
+		overrides[i] = gog_series_get_overrides (GOG_SERIES (series));
 		if (gog_error_bar_is_visible (series->errors)) 
 			error_data[i] = g_malloc (sizeof (ErrorBarData) * lengths[i]);
 		else 
@@ -465,7 +464,6 @@ gog_barcol_view_render (GogView *view, GogViewAllocation const *bbox)
 		pos_base = neg_base = 0.0;
 		ptr = gog_1_5d_model->base.series;
 		for (j = 0 ; j < num_series ; j++) {
-			overrides = gog_series_get_overrides (GOG_SERIES (ptr->data));
 			work.y = (double) j * col_step + (double) i - offset + 1.0;
 			
 			if (i >= lengths[j])
@@ -492,10 +490,10 @@ gog_barcol_view_render (GogView *view, GogViewAllocation const *bbox)
 			}
 
 			gse = NULL;
-			if ((overrides != NULL) &&
-				(GOG_SERIES_ELEMENT (overrides->data)->index == i)) {
-					gse = GOG_SERIES_ELEMENT (overrides->data);
-					overrides = overrides->next;
+			if ((overrides[j] != NULL) &&
+				(GOG_SERIES_ELEMENT (overrides[j]->data)->index == i)) {
+					gse = GOG_SERIES_ELEMENT (overrides[j]->data);
+					overrides[j] = overrides[j]->next;
 					gog_renderer_push_style (view->renderer,
 						gog_styled_object_get_style (
 							GOG_STYLED_OBJECT (gse)));
