@@ -240,7 +240,7 @@ gog_xyz_plot_update (GogObject *obj)
 	go_data_matrix_get_minmax (mat, &tmp_min, &tmp_max);
 	if ((tmp_min != model->z.minima)
 			|| (tmp_max != model->z.maxima)) {
-		model->z.minima = tmp_min - 0.5 * fabs (tmp_max - tmp_min);
+		model->z.minima = tmp_min;
 		model->z.maxima = tmp_max;
 		gog_axis_bound_changed (
 			model->base.axis[GOG_XYZ_PLOT_GET_CLASS (model)->third_axis],
@@ -285,7 +285,7 @@ gog_xyz_plot_axis_get_bounds (GogPlot *plot, GogAxisType axis,
 	}
 	if (bounds->fmt == NULL && fmt != NULL)
 		bounds->fmt = go_format_ref (fmt);
-	if (go_finite (min)) {
+	if (go_finite (min) && vec) {
 		bounds->logical.minima = bounds->val.minima = min;
 		bounds->logical.maxima = bounds->val.maxima = max;
 		bounds->is_discrete = FALSE;
@@ -403,7 +403,6 @@ gog_xyz_plot_class_init (GogXYZPlotClass *klass)
 	}
 
 	/* Fill in GogPlotClass methods */
-	gog_plot_klass->desc.num_series_min = 1;
 	gog_plot_klass->desc.num_series_max = 1;
 	gog_plot_klass->series_type = gog_xyz_series_get_type();
 	gog_plot_klass->axis_get_bounds	= gog_xyz_plot_axis_get_bounds;
@@ -513,6 +512,7 @@ go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
 	gog_contour_view_register_type (module);
 	gog_surface_plot_register_type (module);
 	gog_surface_view_register_type (module);
+	gog_xyz_contour_plot_register_type (module);
 	gog_xyz_surface_plot_register_type (module);
 	gog_xyz_series_register_type (module);
 	xl_xyz_series_register_type (module);
